[U-Boot] [PATCH 4/8] spi: Rename op_mode_rx to mode_rx

Jagan Teki jteki at openedev.com
Wed Dec 16 16:40:43 CET 2015


Since spi rx mode macro's are renamed to simple and
meaninfull in below patch, this patch will rename
the respective structure member.
"spi: Rename SPI_OPM_RX_* to SPI_RX_*"
(sha1: 5e9ffbc5376616449beaaf2bc100f579f12291cf)

Cc: Simon Glass <sjg at chromium.org>
Cc: Bin Meng <bmeng.cn at gmail.com>
Cc: Michal Simek <michal.simek at xilinx.com>
Cc: Siva Durga Prasad Paladugu <sivadur at xilinx.com>
Signed-off-by: Jagan Teki <jteki at openedev.com>
---
 drivers/mtd/spi/spi_flash.c | 2 +-
 drivers/spi/ich.c           | 2 +-
 drivers/spi/ti_qspi.c       | 2 +-
 include/spi.h               | 4 ++--
 4 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/mtd/spi/spi_flash.c b/drivers/mtd/spi/spi_flash.c
index 1ba6222..51f94a7 100644
--- a/drivers/mtd/spi/spi_flash.c
+++ b/drivers/mtd/spi/spi_flash.c
@@ -1098,7 +1098,7 @@ int spi_flash_scan(struct spi_flash *flash)
 	flash->sector_size = flash->erase_size;
 
 	/* Look for the fastest read cmd */
-	cmd = fls(params->e_rd_cmd & spi->op_mode_rx);
+	cmd = fls(params->e_rd_cmd & spi->mode_rx);
 	if (cmd) {
 		cmd = spi_read_cmds_array[cmd - 1];
 		flash->read_cmd = cmd;
diff --git a/drivers/spi/ich.c b/drivers/spi/ich.c
index 7f41763..59eaaea 100644
--- a/drivers/spi/ich.c
+++ b/drivers/spi/ich.c
@@ -752,7 +752,7 @@ static int ich_spi_child_pre_probe(struct udevice *dev)
 	 * and byte program command for SST flash
 	 */
 	if (plat->ich_version == 7) {
-		slave->op_mode_rx = SPI_RX_SLOW;
+		slave->mode_rx = SPI_RX_SLOW;
 		slave->mode = SPI_TX_BYTE;
 	}
 
diff --git a/drivers/spi/ti_qspi.c b/drivers/spi/ti_qspi.c
index 366243c..26616eb 100644
--- a/drivers/spi/ti_qspi.c
+++ b/drivers/spi/ti_qspi.c
@@ -115,7 +115,7 @@ static void ti_spi_setup_spi_register(struct ti_qspi_slave *qslave)
 			QSPI_SETUP0_NUM_D_BYTES_8_BITS |
 			QSPI_SETUP0_READ_QUAD | QSPI_CMD_WRITE |
 			QSPI_NUM_DUMMY_BITS);
-	slave->op_mode_rx = SPI_RX_QUAD;
+	slave->mode_rx = SPI_RX_QUAD;
 #else
 	memval |= QSPI_CMD_READ | QSPI_SETUP0_NUM_A_BYTES |
 			QSPI_SETUP0_NUM_D_BYTES_NO_BITS |
diff --git a/include/spi.h b/include/spi.h
index fd09502..48a78dc 100644
--- a/include/spi.h
+++ b/include/spi.h
@@ -99,7 +99,7 @@ struct dm_spi_slave_platdata {
  *			bus (bus->seq) so does not need to be stored
  * @cs:			ID of the chip select connected to the slave.
  * @mode:		SPI mode to use for this slave (see SPI mode flags)
  * @op_mode_rx:		SPI RX operation mode.
  * @wordlen:		Size of SPI word in number of bits
  * @max_write_size:	If non-zero, the maximum number of bytes which can
  *			be written at once, excluding command bytes.
@@ -117,7 +117,7 @@ struct spi_slave {
 	unsigned int cs;
 #endif
 	uint mode;
-	u8 op_mode_rx;
+	u8 mode_rx;
 	unsigned int wordlen;
 	unsigned int max_write_size;
 	void *memory_map;
@@ -99,7 +99,7 @@ struct dm_spi_slave_platdata {
  * @cs:			ID of the chip select connected to the slave.
  * @mode:		SPI mode to use for this slave (see SPI mode flags)
- * @op_mode_rx:		SPI RX operation mode.
+ * @mode_rx:		SPI RX mode to use for this slave
  * @wordlen:		Size of SPI word in number of bits
  * @max_write_size:	If non-zero, the maximum number of bytes which can
-- 
1.9.1



More information about the U-Boot mailing list